@@ -303,7 +303,8 @@ def office_activemime(f):
         return "doc"
 
 def msix(f):
-    if f.get_child(b"Registry.dat") and f.get_child(b"AppxManifest.xml"):
+    import code;code.interact(local=dict(locals(), **globals()))
+    if all([pattern in f.contents for pattern in (b"Registry.dat", b"AppxManifest.xml")]):
         return "msix"
 
 def office_zip(f):
@@ -496,9 +497,15 @@ def identify(f, check_shellcode: bool = False):
 
     if f.filename:
         for package, extensions in file_extensions.items():
+            print(package, extensions, f.filename)
             if f.filename.endswith(extensions):
                 return package
 
+    for identifier in identifiers_special:
+        package = identifier(f)
+        if package:
+            return package
+
     # Trusted mimes and magics should be applied before identifiers which could run on files within archives
     if f.mime in trusted_archive_mimes:
         return trusted_archive_mimes[f.mime]
@@ -527,11 +534,13 @@ def identify(f, check_shellcode: bool = False):
     if check_shellcode:
         return detect_shellcode(f)
 
+identifiers_special = [
+    msix,
+]
 
 identifiers = [
     udf,
     dmg,
-    msix,
     office_zip,
     office_ole,
     office_one,
